# Iget

A small CLI


## Installation


    $ pip install iget

## Usage

TODO: Write usage instructions here


## License

The package is available as open source under the terms of the [MIT License](https://opensource.org/licenses/MIT).
